@@ -1,6 +1,8 @@
+from __future__ import annotations
 from io import TextIOWrapper
 
 from Corpus.Sentence import Sentence
+from DependencyParser.ParserEvaluationScore import ParserEvaluationScore
 from FrameNet.FrameNet import FrameNet
 from MorphologicalAnalysis.FsmMorphologicalAnalyzer import FsmMorphologicalAnalyzer
 from PropBank.FramesetList import FramesetList
@@ -31,7 +33,7 @@ class AnnotatedSentence(Sentence):
             if isinstance(fileOrStr, TextIOWrapper):
                 line = fileOrStr.readline()
                 wordArray = line.rstrip().split(" ")
-            elif isinstance(self, str):
+            elif isinstance(fileOrStr, str):
                 wordArray = fileOrStr.split(" ")
             for word in wordArray:
                 if len(word) > 0:
@@ -248,6 +250,15 @@ class AnnotatedSentence(Sentence):
         else:
             return ""
 
+    def compareParses(self, sentence: AnnotatedSentence) -> ParserEvaluationScore:
+        score = ParserEvaluationScore()
+        for i in range(self.wordCount()):
+            relation1 = self.words[i].getUniversalDependency()
+            relation2 = sentence.getWord(i).getUniversalDependency()
+            if relation1 is not None and relation2 is not None:
+                score.add(relation1.compareRelations(relation2))
+        return score
+
     def save(self):
         """
         Saves the current sentence.
